==> v4.5.1.tar.gz: doomretro-4.5.1/src/version.h <==
/*
========================================================================

                           D O O M  R e t r o
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of acknowledgments,
  see <https://github.com/bradharding/doomretro/wiki/ACKNOWLEDGMENTS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#pragma once

#define DOOMRETRO_VERSION               4,5,1,0
#define DOOMRETRO_VERSIONSTRING         "4.5.1"
#define DOOMRETRO_NAMEANDVERSIONSTRING  "DOOM Retro v4.5.1"
#define DOOMRETRO_SAVEGAMEVERSIONSTRING "DOOM Retro v3.6"

#define DOOMRETRO                       "doomretro"
#define DOOMRETRO_CONFIG                "doomretro.cfg"
#define DOOMRETRO_COPYRIGHT             "Copyright \xA9 2013\x962022 by Brad Harding. All rights reserved."
#define DOOMRETRO_CREATOR               "Brad Harding"
#define DOOMRETRO_CREATOREMAIL          "Brad Harding <brad@doomretro.com>"
#define DOOMRETRO_FILENAME              "doomretro.exe"
#define DOOMRETRO_ICONPATH              "..\\res\\doomretro.ico"
#define DOOMRETRO_LICENSE               "GNU General Public License v3.0"
#define DOOMRETRO_MUTEX                 "DOOMRETRO-CC4F1071-8B24-4E91-A207-D792F39636CD"
#define DOOMRETRO_NAME                  "DOOM Retro"
#define DOOMRETRO_PLACEOFORIGIN         "Western Sydney, Australia"
#define DOOMRETRO_SAVE                  "doomretro%i.save"
#define DOOMRETRO_TRADEMARKS            "DOOM is a registered trademark of id Software LLC, a ZeniMax " \
                                        "Media company, in the US and/or other countries, and is used " \
                                        "without permission. All other trademarks are the property of " \
                                        "their respective holders. DOOM Retro is in no way affiliated " \
                                        "with nor endorsed by id Software."
#define DOOMRETRO_WAD                   "doomretro.wad"
#define DOOMRETRO_WIKINAME              "DOOM Retro Wiki"
#define DOOMRETRO_WIKIURL               "https://github.com/bradharding/doomretro/wiki"
#define DOOMRETRO_WIKILICENSEURL        "https://github.com/bradharding/doomretro/wiki/LICENSE"

==> v4.7.1.tar.gz: doomretro-4.7.1/src/version.h <==
/*
========================================================================

                               DOOM Retro
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of acknowledgments,
  see <https://github.com/bradharding/doomretro/wiki/ACKNOWLEDGMENTS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#pragma once

#define DOOMRETRO_VERSION               4,7,1,0
#define DOOMRETRO_VERSIONSTRING         "4.7.1"
#define DOOMRETRO_NAMEANDVERSIONSTRING  "DOOM Retro v4.7.1"
#define DOOMRETRO_SAVEGAMEVERSIONSTRING "DOOM Retro v3.6"

#define DOOMRETRO                       "doomretro"
#define DOOMRETRO_AUTOLOADFOLDER        "autoload"
#define DOOMRETRO_CONFIG                "doomretro.cfg"
#define DOOMRETRO_CONSOLEFOLDER         "console"
#define DOOMRETRO_COPYRIGHT             "Copyright \xA9 2013\x962022 by Brad Harding. All rights reserved."
#define DOOMRETRO_CREATOR               "Brad Harding"
#define DOOMRETRO_CREATORANDEMAIL       "Brad Harding (brad@doomretro.com)"
#define DOOMRETRO_FILENAME              "doomretro.exe"
#define DOOMRETRO_ICONPATH              "..\\res\\doomretro.ico"
#define DOOMRETRO_LICENSE               "GNU General Public License v3.0"
#define DOOMRETRO_LICENSEURL            "https://github.com/bradharding/doomretro/wiki/LICENSE"
#define DOOMRETRO_MUTEX                 "DOOMRETRO-CC4F1071-8B24-4E91-A207-D792F39636CD"
#define DOOMRETRO_NAME                  "DOOM Retro"
#define DOOMRETRO_PLACEOFORIGIN         "Western Sydney, Australia"
#define DOOMRETRO_SAVEGAME              "doomretro%i.save"
#define DOOMRETRO_SAVEGAMESFOLDER       "savegames"
#define DOOMRETRO_SCREENSHOTSFOLDER     "screenshots"
#define DOOMRETRO_TRADEMARKS            "DOOM is a registered trademark of id Software LLC, a ZeniMax " \
                                        "Media company, in the US and/or other countries, and is used " \
                                        "without permission. All other trademarks are the property of " \
                                        "their respective holders. DOOM Retro is in no way affiliated " \
                                        "with nor endorsed by id Software."
#define DOOMRETRO_WAD                   "doomretro.wad"
#define DOOMRETRO_WIKINAME              "DOOM Retro Wiki"
#define DOOMRETRO_WIKIURL               "https://github.com/bradharding/doomretro/wiki"
